@@ -6,7 +6,7 @@ package SPVM::EqualityChecker;
 
 SPVM::EqualityChecker - Interface Type for Object Equality Checking Callback
 
-=head1 Synopsys
+=head1 Usage
   
   use EqualityChecker;
   use Point;
@@ -23,8 +23,8 @@ SPVM::EqualityChecker - Interface Type for Object Equality Checking Callback
     }
   };
   
-  my $point1 = Point->new_xy(1, 2);
-  my $point2 = Point->new_xy(5, 6);
+  my $point1 = Point->new(1, 2);
+  my $point2 = Point->new(5, 6);
   
   my $is_equal = $equality_checker->($point1, $point2);
 
